@@ -11,6 +11,12 @@ class AHomePage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
     template = '%s/home_page.html' % constants.PAGES_TEMPLATES_PATH
     content_panels = GenericPage.content_panels
 
+    subpage_types = [
+        'cms.ContentPage',
+        'cms.DocumentPage',
+        'cms.BlogIndexPage',
+    ]
+
     class Meta:
         abstract = True
         app_label = 'cms'
